package CPAN::Test::Dummy::Perl5::SKAJI v0.0.24;
use v5.24;
use warnings;
use experimental qw(lexical_subs signatures);

our $TRIAL = 0;

1;
__END__

=encoding utf-8

=head1 NAME

CPAN::Test::Dummy::Perl5::SKAJI - a test dummy distribution

=head1 SYNOPSIS

  use CPAN::Test::Dummy::Perl5::SKAJI;

=head1 DESCRIPTION

CPAN::Test::Dummy::Perl5::SKAJI is a test dummy distribution.

=head1 ARTIFACT ATTESTATIONS

GitHub Artifact Attestations are generated for release tarballs uploaded to
CPAN. If you care about provenance for the uploaded tarballs, see:

L<https://github.com/skaji/perl-CPAN-Test-Dummy-Perl5-SKAJI/attestations>

=head1 COPYRIGHT AND LICENSE

Copyright 2026 Shoichi Kaji <skaji@cpan.org>

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut
